@@ -39,7 +39,7 @@ as well as possible data fields when declaring new networks."""
 
 DEV_REQUIRED = ("id", "host", "cmd", "cmd_settings")
 PROD_REQUIRED = ("id", "host", "chainid")
-OPTIONAL = ("name", "explorer")
+OPTIONAL = ("name", "explorer", "timeout")
 
 DEV_CMD_SETTINGS = (
     "port",
@@ -49,6 +49,9 @@ DEV_CMD_SETTINGS = (
     "fork",
     "mnemonic",
     "account_keys_path",
+    "block_time",
+    "default_balance",
+    "time",
 )
 
 
@@ -112,8 +115,10 @@ def _add(env, id_, *args):
             "id": id_,
             "cmd": args.pop("cmd"),
             "host": args.pop("host"),
-            "cmd_settings": args,
         }
+        if "timeout" in args:
+            new["timeout"] = args.pop("timeout")
+        new["cmd_settings"] = args
         _validate_network(new, DEV_REQUIRED)
         networks["development"].append(new)
     else:
